#pragma once

#include <entt/entt.hpp>
#include <components.h>

class SceneManager {
public:
    SceneManager(entt::registry& registry) : registry(registry), activeScene(entt::null) {}

    void SetActiveScene(entt::entity scene) {
        if (activeScene != entt::null) {
            auto& currentScene = registry.get<SceneComponent>(activeScene);
            currentScene.isActive = false;
        }

        activeScene = scene;
        auto& newScene = registry.get<SceneComponent>(activeScene);
        newScene.isActive = true;
    }

    entt::entity CreateScene() {
        entt::entity scene = registry.create();
        registry.emplace<SceneComponent>(scene, false);
        return scene;
    }

    void UpdateActiveScene() {
        if (activeScene != entt::null) {
            // Iterate over entities in the active scene that have an InputComponent
            auto view = registry.view<InputComponent>();
            for (auto entity : view) {
                auto& inputComponent = view.get<InputComponent>(entity);
                inputComponent.Update(); // This will call the input logic
            }
        }
    }

    void RenderActiveScene() {
        if (activeScene != entt::null) {
            // Iterate over entities in the active scene that have both SpriteComponent and TransformComponent
            auto view = registry.view<SpriteComponent, TransformComponent>();
            for (auto entity : view) {
                auto& sprite = view.get<SpriteComponent>(entity);
                auto& transform = view.get<TransformComponent>(entity);

                // Render the sprite at the position defined by the TransformComponent
                sprite.Render(transform);
            }
        }
    }


private:
    entt::registry& registry;
    entt::entity activeScene;
};
